@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.107';
+our $VERSION = '0.108';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Thu Sep 27 03:57:54 2018 GMT
+# on Sat Oct  6 17:58:12 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1692,11 +1692,11 @@ __PACKAGE__->status( add => 24796, iridium => '-', 'Iridium 4', 'Tumbling' );
 __PACKAGE__->status( add => 24836, iridium => '-', 'Iridium 914', 'Tumbling' );
 __PACKAGE__->status( add => 24837, iridium => 'D', 'Iridium 12', 'Decayed 2018-09-02' );
 __PACKAGE__->status( add => 24838, iridium => 'D', 'Iridium 9', 'Decayed 2003-03-11' );
-__PACKAGE__->status( add => 24839, iridium => '-', 'Iridium 10', 'Tumbling' );
+__PACKAGE__->status( add => 24839, iridium => 'D', 'Iridium 10', 'Decayed 2018-10-06' );
 __PACKAGE__->status( add => 24840, iridium => 'D', 'Iridium 13', 'Decayed 2018-04-29' );
 __PACKAGE__->status( add => 24841, iridium => '-', 'Iridium 16', 'Tumbling' );
 __PACKAGE__->status( add => 24842, iridium => '-', 'Iridium 911', 'Tumbling' );
-__PACKAGE__->status( add => 24869, iridium => 'S', 'Iridium 15', '' );
+__PACKAGE__->status( add => 24869, iridium => '-', 'Iridium 15', 'Tumbling' );
 __PACKAGE__->status( add => 24870, iridium => '-', 'Iridium 17', 'Tumbling' );
 __PACKAGE__->status( add => 24871, iridium => '-', 'Iridium 920', 'Tumbling' );
 __PACKAGE__->status( add => 24872, iridium => 'D', 'Iridium 18', 'Decayed 2018-08-19' );
@@ -1736,7 +1736,7 @@ __PACKAGE__->status( add => 25169, iridium => '+', 'Iridium 52', '' );
 __PACKAGE__->status( add => 25170, iridium => '-', 'Iridium 56', 'Tumbling' );
 __PACKAGE__->status( add => 25171, iridium => '+', 'Iridium 54', '' );
 __PACKAGE__->status( add => 25172, iridium => 'D', 'Iridium 50', 'Decayed 2018-09-23' );
-__PACKAGE__->status( add => 25173, iridium => '-', 'Iridium 53', 'Tumbling' );
+__PACKAGE__->status( add => 25173, iridium => 'D', 'Iridium 53', 'Decayed 2018-09-30' );
 __PACKAGE__->status( add => 25262, iridium => '-', 'Iridium 51', 'Tumbling' );
 __PACKAGE__->status( add => 25263, iridium => 'S', 'Iridium 61', '' );
 __PACKAGE__->status( add => 25272, iridium => 'S', 'Iridium 55', '' );
@@ -1753,7 +1753,7 @@ __PACKAGE__->status( add => 25290, iridium => 'D', 'Iridium 67', 'Decayed 2018-0
 __PACKAGE__->status( add => 25291, iridium => 'D', 'Iridium 68', 'Decayed 2018-06-06' );
 __PACKAGE__->status( add => 25319, iridium => '-', 'Iridium 69', 'Tumbling' );
 __PACKAGE__->status( add => 25320, iridium => '-', 'Iridium 71', 'Tumbling' );
-__PACKAGE__->status( add => 25342, iridium => 'S', 'Iridium 70', '' );
+__PACKAGE__->status( add => 25342, iridium => '-', 'Iridium 70', 'Tumbling' );
 __PACKAGE__->status( add => 25343, iridium => 'D', 'Iridium 72', 'Decayed 2018-05-14' );
 __PACKAGE__->status( add => 25344, iridium => '-', 'Iridium 73', 'Tumbling' );
 __PACKAGE__->status( add => 25345, iridium => 'D', 'Iridium 74', 'Decayed 2017-06-11' );
@@ -1766,7 +1766,7 @@ __PACKAGE__->status( add => 25469, iridium => 'D', 'Iridium 80', 'Decayed 2018-0
 __PACKAGE__->status( add => 25470, iridium => 'D', 'Iridium 79', 'Decayed 2000-11-29' );
 __PACKAGE__->status( add => 25471, iridium => 'D', 'Iridium 77', 'Decayed 2017-09-22' );
 __PACKAGE__->status( add => 25527, iridium => '-', 'Iridium 2', 'Tumbling' );
-__PACKAGE__->status( add => 25528, iridium => '-', 'Iridium 86', 'Tumbling' );
+__PACKAGE__->status( add => 25528, iridium => 'D', 'Iridium 86', 'Decayed 2018-10-05' );
 __PACKAGE__->status( add => 25529, iridium => 'D', 'Iridium 85', 'Decayed 2000-12-30' );
 __PACKAGE__->status( add => 25530, iridium => '-', 'Iridium 84', 'Tumbling' );
 __PACKAGE__->status( add => 25531, iridium => '+', 'Iridium 83', '' );
@@ -1784,9 +1784,9 @@ __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-0
 
 # Summary:
 # Operational [+]: 10
-#       Spare [S]: 12
-#    Tumbling [-]: 38
-#     Decayed [D]: 37
+#       Spare [S]: 10
+#    Tumbling [-]: 37
+#     Decayed [D]: 40
 
 1;
 
